//===================================================================
//UpdateCount.js
//一定間隔で処理を実行したい時に使うプラグイン
//===================================================================
//Copyright (c) 2017 蔦森くいな
//Released under the MIT license.
//http://opensource.org/licenses/mit-license.php
//-------------------------------------------------------------------
//blog   : http://paradre.com/
//Twitter: https://twitter.com/Kuina_T
//===================================================================
//＜更新情報＞
//  ver1.0.0 2017/07/30 不具合修正
//  ver1.0.0 2017/07/30 初版
//===================================================================

/*:
 * @plugindesc フレーム更新回数を取得したり一定間隔で処理を実行したい時に使います
 * @author 蔦森くいな
 *
 * @help 「並列処理」イベントにイベントコマンド「条件分岐」を設定し、
 * 条件「スクリプト」の記入欄に以下のようなコマンドを入力します。
 * 
 * $gameMap.pd_UC_repeatInterval(60)
 * 
 * ( )内に指定したフレーム数毎に１回の間隔で
 * 条件分岐の中に設定した処理が実行されます（60フレームは1秒）
 * 
 * 
 * また、スクリプトを扱える方は以下の関数が使用できます（こちらが本来の用途）
 * Graphics.frameCountの値を参照すると実際の処理回数とはズレが生じるため
 * 繰り返し処理には以下の関数を利用する方が確実だと思われます。
 * 
 * ============================================================
 * $gameMap._pd_UC_updateCount
 * ------------------------------------------------------------
 * マップシーンの処理が更新された回数を取得します。
 * この値はニューゲーム時点を０として増え続け、セーブデータにも記録されます。
 * メニュー画面やバトル画面など、マップ以外のシーンはカウントされません。
 * 
 * ============================================================
 * SceneManager._pd_UC_updateCount
 * ------------------------------------------------------------
 * ゲーム起動時からの処理が更新された回数を取得します。
 * この値はゲーム起動時点を０として増え続け、セーブデータには記録されません。
 * メニュー画面やバトル画面など、マップ以外のシーンでもカウントされます。
 * 
 * ============================================================
 * $gameMap.pd_UC_repeatInterval(frame)
 * ------------------------------------------------------------
 * 引数に指定したフレーム毎に一定間隔でtrueを返します。
 * マップ以外のシーンでは更新回数がカウントされないので
 * メニュー画面など他のシーンから戻った時でも一定の更新間隔を維持できます。
 * 
 * ============================================================
 * SceneManager.pd_UC_repeatInterval(frame)
 * ------------------------------------------------------------
 * 引数に指定したフレーム毎に一定間隔でtrueを返します。
 * マップ以外のシーンでも更新回数がカウントされるので
 * ゲーム全体を通して繰り返し処理したい内容に利用できます。
 * ============================================================
 * 
 *
 * 利用規約：
 * このプラグインは商用・非商用を問わず無料でご利用いただけます。
 * 使用報告やクレジット表記も必要ありません。
 * どのようなゲームに使っても、どのように加工していただいても構いません。
 * MIT Licenseにつき著作権表示とライセンスURLは残しておいて下さい。
 */

(function() {
    'use strict';
    
    var pd_UC_SceneManager_initialize = SceneManager.initialize;
    SceneManager.initialize = function() {
        this._pd_UC_updateCount = 0;
        pd_UC_SceneManager_initialize.call(this);
    };
    
    var pd_UC_SceneManager_updateScene = SceneManager.updateScene;
    SceneManager.updateScene = function() {
        pd_UC_SceneManager_updateScene.call(this);
        this._pd_UC_updateCount++;
    };
    
    SceneManager.prototype.pd_UC_repeatInterval = function(frame) {
        if(this._pd_UC_updateCount % frame === 0){
            return true;
        }
        return false;
    };
    
    var pd_UC_Game_Map_initialize = Game_Map.prototype.initialize;
    Game_Map.prototype.initialize = function() {
        pd_UC_Game_Map_initialize.call(this);
        this._pd_UC_updateCount = 0;
    };
    
    var pd_UC_Game_Map_update = Game_Map.prototype.update;
    Game_Map.prototype.update = function(sceneActive) {
        this._pd_UC_updateCount++;
        pd_UC_Game_Map_update.call(this, sceneActive);
    };
    
    Game_Map.prototype.pd_UC_repeatInterval = function(frame) {
        if(this._pd_UC_updateCount % frame === 0){
            return true;
        }
        return false;
    };
    
})();